@@ -873,64 +873,6 @@ impl ChunkAggSeries for ListChunked {
 #[cfg(feature = "object")]
 impl<T: PolarsObject> ChunkAggSeries for ObjectChunked<T> {}
 
-impl<T> ArgAgg for ChunkedArray<T>
-where
-    T: PolarsNumericType,
-{
-    fn arg_min(&self) -> Option<usize> {
-        match self.is_sorted_flag2() {
-            IsSorted::Ascending => Some(0),
-            IsSorted::Descending => Some(self.len()),
-            IsSorted::Not => self
-                .into_iter()
-                .enumerate()
-                .reduce(|acc, (idx, val)| if acc.1 > val { (idx, val) } else { acc })
-                .map(|tpl| tpl.0),
-        }
-    }
-    fn arg_max(&self) -> Option<usize> {
-        match self.is_sorted_flag2() {
-            IsSorted::Ascending => Some(self.len()),
-            IsSorted::Descending => Some(0),
-            IsSorted::Not => self
-                .into_iter()
-                .enumerate()
-                .reduce(|acc, (idx, val)| if acc.1 < val { (idx, val) } else { acc })
-                .map(|tpl| tpl.0),
-        }
-    }
-}
-
-impl ArgAgg for BooleanChunked {
-    fn arg_min(&self) -> Option<usize> {
-        if self.is_empty() || self.null_count() == self.len() {
-            None
-        } else if self.all() {
-            Some(0)
-        } else {
-            self.into_iter()
-                .position(|opt_val| matches!(opt_val, Some(false)))
-        }
-    }
-    fn arg_max(&self) -> Option<usize> {
-        if self.is_empty() || self.null_count() == self.len() {
-            None
-        } else if self.any() {
-            self.into_iter()
-                .position(|opt_val| matches!(opt_val, Some(true)))
-        } else {
-            Some(0)
-        }
-    }
-}
-impl ArgAgg for Utf8Chunked {}
-#[cfg(feature = "dtype-binary")]
-impl ArgAgg for BinaryChunked {}
-impl ArgAgg for ListChunked {}
-
-#[cfg(feature = "object")]
-impl<T: PolarsObject> ArgAgg for ObjectChunked<T> {}
-
 #[cfg(test)]
 mod test {
     use polars_arrow::prelude::QuantileInterpolOptions;
