@@ -55,19 +55,27 @@ fn sort_branch<T, Fd, Fr>(
     reverse: bool,
     default_order_fn: Fd,
     reverse_order_fn: Fr,
+    parallel: bool,
 ) where
     T: PartialOrd + Send,
     Fd: FnMut(&T, &T) -> Ordering + for<'r, 's> Fn(&'r T, &'s T) -> Ordering + Sync,
     Fr: FnMut(&T, &T) -> Ordering + for<'r, 's> Fn(&'r T, &'s T) -> Ordering + Sync,
 {
-    match reverse {
-        true => slice.par_sort_unstable_by(reverse_order_fn),
-        false => slice.par_sort_unstable_by(default_order_fn),
+    if parallel {
+        match reverse {
+            true => slice.par_sort_unstable_by(reverse_order_fn),
+            false => slice.par_sort_unstable_by(default_order_fn),
+        }
+    } else {
+        match reverse {
+            true => slice.sort_unstable_by(reverse_order_fn),
+            false => slice.sort_unstable_by(default_order_fn),
+        }
     }
 }
 
 #[cfg(feature = "private")]
-pub fn argsort_no_nulls<Idx, T>(slice: &mut [(Idx, T)], reverse: bool)
+pub fn argsort_no_nulls<Idx, T>(slice: &mut [(Idx, T)], reverse: bool, parallel: bool)
 where
     T: PartialOrd + Send + IsFloat,
     Idx: PartialOrd + Send,
@@ -77,6 +85,7 @@ where
         reverse,
         |(_, a), (_, b)| compare_fn_nan_max(a, b),
         |(_, a), (_, b)| compare_fn_nan_max(b, a),
+        parallel,
     );
 }
 
@@ -85,14 +94,22 @@ pub fn argsort_branch<T, Fd, Fr>(
     reverse: bool,
     default_order_fn: Fd,
     reverse_order_fn: Fr,
+    parallel: bool,
 ) where
     T: PartialOrd + Send,
     Fd: FnMut(&T, &T) -> Ordering + for<'r, 's> Fn(&'r T, &'s T) -> Ordering + Sync,
     Fr: FnMut(&T, &T) -> Ordering + for<'r, 's> Fn(&'r T, &'s T) -> Ordering + Sync,
 {
-    match reverse {
-        true => slice.par_sort_by(reverse_order_fn),
-        false => slice.par_sort_by(default_order_fn),
+    if parallel {
+        match reverse {
+            true => slice.par_sort_by(reverse_order_fn),
+            false => slice.par_sort_by(default_order_fn),
+        }
+    } else {
+        match reverse {
+            true => slice.sort_by(reverse_order_fn),
+            false => slice.sort_by(default_order_fn),
+        }
     }
 }
 
@@ -153,7 +170,7 @@ where
     T: PolarsNumericType,
 {
     sort_with_fast_path!(ca, options);
-    if !ca.has_validity() {
+    if ca.null_count() == 0 {
         let mut vals = memcpy_values(ca);
 
         sort_branch(
@@ -161,6 +178,7 @@ where
             options.descending,
             order_default,
             order_reverse,
+            options.multithreaded,
         );
 
         let mut ca = ChunkedArray::from_vec(ca.name(), vals);
@@ -192,7 +210,13 @@ where
             &mut vals[null_count..]
         };
 
-        sort_branch(mut_slice, options.descending, order_default, order_reverse);
+        sort_branch(
+            mut_slice,
+            options.descending,
+            order_default,
+            order_reverse,
+            options.multithreaded,
+        );
 
         let mut ca: ChunkedArray<T> = if options.nulls_last {
             vals.extend(std::iter::repeat(T::Native::default()).take(ca.null_count()));
@@ -253,7 +277,7 @@ where
             vals.extend_trusted_len(iter);
         });
 
-        argsort_no_nulls(vals.as_mut_slice(), reverse);
+        argsort_no_nulls(vals.as_mut_slice(), reverse, options.multithreaded);
 
         let out: NoNull<IdxCa> = vals.into_iter().map(|(idx, _v)| idx).collect_trusted();
         let mut out = out.into_inner();
@@ -403,6 +427,7 @@ impl ChunkSort<Utf8Type> for Utf8Chunked {
             options.descending,
             order_default,
             order_reverse,
+            options.multithreaded,
         );
 
         let mut values = Vec::<u8>::with_capacity(self.get_values_size());
@@ -486,6 +511,7 @@ impl ChunkSort<Utf8Type> for Utf8Chunked {
         self.sort_with(SortOptions {
             descending: reverse,
             nulls_last: false,
+            multithreaded: true,
         })
     }
 
@@ -539,6 +565,7 @@ impl ChunkSort<BinaryType> for BinaryChunked {
             options.descending,
             order_default,
             order_reverse,
+            options.multithreaded,
         );
 
         let mut values = Vec::<u8>::with_capacity(self.get_values_size());
@@ -622,6 +649,7 @@ impl ChunkSort<BinaryType> for BinaryChunked {
         self.sort_with(SortOptions {
             descending: reverse,
             nulls_last: false,
+            multithreaded: true,
         })
     }
 
@@ -684,6 +712,7 @@ impl ChunkSort<BooleanType> for BooleanChunked {
         self.sort_with(SortOptions {
             descending: reverse,
             nulls_last: false,
+            multithreaded: true,
         })
     }
 
@@ -793,6 +822,7 @@ mod test {
         let out = a.sort_with(SortOptions {
             descending: false,
             nulls_last: false,
+            multithreaded: true,
         });
         assert_eq!(
             Vec::from(&out),
@@ -810,6 +840,7 @@ mod test {
         let out = a.sort_with(SortOptions {
             descending: false,
             nulls_last: true,
+            multithreaded: true,
         });
         assert_eq!(
             Vec::from(&out),
@@ -890,6 +921,7 @@ mod test {
         let out = ca.sort_with(SortOptions {
             descending: false,
             nulls_last: false,
+            multithreaded: true,
         });
         let expected = &[None, None, Some("a"), Some("b"), Some("c")];
         assert_eq!(Vec::from(&out), expected);
@@ -897,6 +929,7 @@ mod test {
         let out = ca.sort_with(SortOptions {
             descending: true,
             nulls_last: false,
+            multithreaded: true,
         });
 
         let expected = &[None, None, Some("c"), Some("b"), Some("a")];
@@ -905,6 +938,7 @@ mod test {
         let out = ca.sort_with(SortOptions {
             descending: false,
             nulls_last: true,
+            multithreaded: true,
         });
         let expected = &[Some("a"), Some("b"), Some("c"), None, None];
         assert_eq!(Vec::from(&out), expected);
@@ -912,6 +946,7 @@ mod test {
         let out = ca.sort_with(SortOptions {
             descending: true,
             nulls_last: true,
+            multithreaded: true,
         });
         let expected = &[Some("c"), Some("b"), Some("a"), None, None];
         assert_eq!(Vec::from(&out), expected);
