@@ -253,7 +253,7 @@ impl DataFrame {
         let mut iter = value_vars.iter().map(|v| {
             schema
                 .get(v)
-                .ok_or_else(|| PolarsError::NotFound(v.to_string().into()))
+                .ok_or_else(|| PolarsError::ColumnNotFound(v.to_string().into()))
         });
         let mut st = iter.next().unwrap()?.clone();
         for dt in iter {
