@@ -391,8 +391,18 @@ fn map_arrays_to_series(name: &str, chunks: Vec<ArrayRef>) -> PolarsResult<Serie
     let chunks = chunks
         .iter()
         .map(|arr| {
+            // we convert the map to the logical type: List<struct<key, value>>
             let arr = arr.as_any().downcast_ref::<MapArray>().unwrap();
-            arr.field().clone()
+            let inner = arr.field().clone();
+
+            // map has i32 offsets
+            let data_type = ListArray::<i32>::default_datatype(inner.data_type().clone());
+            Box::new(ListArray::<i32>::new(
+                data_type,
+                arr.offsets().clone(),
+                inner,
+                arr.validity().cloned(),
+            )) as ArrayRef
         })
         .collect::<Vec<_>>();
     Series::try_from((name, chunks))
