@@ -327,7 +327,6 @@ pub trait SeriesTrait:
     /// Take by index from an iterator. This operation clones the data.
     /// todo! remove?
     #[cfg(feature = "take_opt_iter")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "take_opt_iter")))]
     fn take_opt_iter(&self, _iter: &mut dyn TakeIteratorNulls) -> PolarsResult<Series> {
         invalid_operation_panic!(self)
     }
@@ -442,16 +441,6 @@ pub trait SeriesTrait:
         invalid_operation_panic!(self)
     }
 
-    /// Get min index
-    fn arg_min(&self) -> Option<usize> {
-        None
-    }
-
-    /// Get max index
-    fn arg_max(&self) -> Option<usize> {
-        None
-    }
-
     /// Get a mask of the null values.
     fn is_null(&self) -> BooleanChunked {
         invalid_operation_panic!(self)
@@ -515,46 +504,6 @@ pub trait SeriesTrait:
         invalid_operation_panic!(self)
     }
 
-    /// Replace None values with one of the following strategies:
-    /// * Forward fill (replace None with the previous value)
-    /// * Backward fill (replace None with the next value)
-    /// * Mean fill (replace None with the mean of the whole array)
-    /// * Min fill (replace None with the minimum of the whole array)
-    /// * Max fill (replace None with the maximum of the whole array)
-    ///
-    /// *NOTE: If you want to fill the Nones with a value use the
-    /// [`fill_null` operation on `ChunkedArray<T>`](../chunked_array/ops/trait.ChunkFillNull.html)*.
-    ///
-    /// # Example
-    ///
-    /// ```rust
-    /// # use polars_core::prelude::*;
-    /// fn example() -> PolarsResult<()> {
-    ///     let s = Series::new("some_missing", &[Some(1), None, Some(2)]);
-    ///
-    ///     let filled = s.fill_null(FillNullStrategy::Forward(None))?;
-    ///     assert_eq!(Vec::from(filled.i32()?), &[Some(1), Some(1), Some(2)]);
-    ///
-    ///     let filled = s.fill_null(FillNullStrategy::Backward(None))?;
-    ///     assert_eq!(Vec::from(filled.i32()?), &[Some(1), Some(2), Some(2)]);
-    ///
-    ///     let filled = s.fill_null(FillNullStrategy::Min)?;
-    ///     assert_eq!(Vec::from(filled.i32()?), &[Some(1), Some(1), Some(2)]);
-    ///
-    ///     let filled = s.fill_null(FillNullStrategy::Max)?;
-    ///     assert_eq!(Vec::from(filled.i32()?), &[Some(1), Some(2), Some(2)]);
-    ///
-    ///     let filled = s.fill_null(FillNullStrategy::Mean)?;
-    ///     assert_eq!(Vec::from(filled.i32()?), &[Some(1), Some(1), Some(2)]);
-    ///
-    ///     Ok(())
-    /// }
-    /// example();
-    /// ```
-    fn fill_null(&self, _strategy: FillNullStrategy) -> PolarsResult<Series> {
-        invalid_operation_panic!(self)
-    }
-
     /// Get the sum of the Series as a new Series of length 1.
     ///
     /// If the [`DataType`] is one of `{Int8, UInt8, Int16, UInt16}` the `Series` is
@@ -601,7 +550,6 @@ pub trait SeriesTrait:
     }
 
     #[cfg(feature = "object")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "object")))]
     /// Get the value at this index as a downcastable Any trait ref.
     fn get_object(&self, _index: usize) -> Option<&dyn PolarsObjectSafe> {
         invalid_operation_panic!(self)
@@ -631,37 +579,25 @@ pub trait SeriesTrait:
 
     /// Check if elements of this Series are in the right Series, or List values of the right Series.
     #[cfg(feature = "is_in")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "is_in")))]
     fn is_in(&self, _other: &Series) -> PolarsResult<BooleanChunked> {
         invalid_operation_panic!(self)
     }
     #[cfg(feature = "repeat_by")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "repeat_by")))]
     fn repeat_by(&self, _by: &IdxCa) -> ListChunked {
         invalid_operation_panic!(self)
     }
     #[cfg(feature = "checked_arithmetic")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "checked_arithmetic")))]
     fn checked_div(&self, _rhs: &Series) -> PolarsResult<Series> {
         invalid_operation_panic!(self)
     }
 
-    #[cfg(feature = "is_first")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "is_first")))]
-    /// Get a mask of the first unique values.
-    fn is_first(&self) -> PolarsResult<BooleanChunked> {
-        invalid_operation_panic!(self)
-    }
-
     #[cfg(feature = "mode")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "mode")))]
     /// Compute the most occurring element in the array.
     fn mode(&self) -> PolarsResult<Series> {
         invalid_operation_panic!(self)
     }
 
     #[cfg(feature = "rolling_window")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "rolling_window")))]
     /// Apply a custom function over a rolling/ moving window of the array.
     /// This has quite some dynamic dispatch, so prefer rolling_min, max, mean, sum over this.
     fn rolling_apply(
@@ -672,7 +608,6 @@ pub trait SeriesTrait:
         panic!("rolling apply not implemented for this dtype. Only implemented for numeric data.")
     }
     #[cfg(feature = "concat_str")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "concat_str")))]
     /// Concat the values into a string array.
     /// # Arguments
     ///
