@@ -1,11 +1,16 @@
 use std::borrow::Cow;
 
+#[cfg(feature = "timezones")]
+use once_cell::sync::Lazy;
 use polars_arrow::utils::CustomIterTools;
 #[cfg(feature = "regex")]
 use regex::{escape, Regex};
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
 
+#[cfg(feature = "timezones")]
+static TZ_AWARE_RE: Lazy<Regex> = Lazy::new(|| Regex::new(r"(%z)|(%:z)|(%#z)|(^%\+$)").unwrap());
+
 use super::*;
 
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
@@ -53,6 +58,8 @@ pub enum StringFunction {
     Strip(Option<String>),
     RStrip(Option<String>),
     LStrip(Option<String>),
+    #[cfg(feature = "string_from_radix")]
+    FromRadix(Option<u32>),
 }
 
 impl Display for StringFunction {
@@ -85,6 +92,8 @@ impl Display for StringFunction {
             StringFunction::Strip(_) => "strip",
             StringFunction::LStrip(_) => "lstrip",
             StringFunction::RStrip(_) => "rstrip",
+            #[cfg(feature = "string_from_radix")]
+            StringFunction::FromRadix { .. } => "from_radix",
         };
 
         write!(f, "str.{s}")
@@ -308,6 +317,24 @@ pub(super) fn count_match(s: &Series, pat: &str) -> PolarsResult<Series> {
 
 #[cfg(feature = "temporal")]
 pub(super) fn strptime(s: &Series, options: &StrpTimeOptions) -> PolarsResult<Series> {
+    let tz_aware = match (options.tz_aware, &options.fmt) {
+        (true, Some(_)) => true,
+        (true, None) => {
+            return Err(PolarsError::ComputeError(
+                "Passing 'tz_aware=True' without 'fmt' is not yet supported. Please specify 'fmt'."
+                    .into(),
+            ));
+        }
+        #[cfg(feature = "timezones")]
+        (false, Some(fmt)) => TZ_AWARE_RE.is_match(fmt),
+        (false, _) => false,
+    };
+    #[cfg(feature = "timezones")]
+    if !tz_aware && options.utc {
+        return Err(PolarsError::ComputeError(
+            "Cannot use 'utc=True' with tz-naive data. Parse the data as naive, and then use `.dt.convert_time_zone('UTC')`.".into(),
+        ));
+    }
     let ca = s.utf8()?;
 
     let out = match &options.date_dtype {
@@ -319,12 +346,24 @@ pub(super) fn strptime(s: &Series, options: &StrpTimeOptions) -> PolarsResult<Se
                 ca.as_date_not_exact(options.fmt.as_deref())?.into_series()
             }
         }
-        DataType::Datetime(tu, _) => {
+        DataType::Datetime(tu, tz) => {
+            if tz.is_some() && tz_aware {
+                return Err(PolarsError::ComputeError(
+                    "Cannot use strptime with both 'tz_aware=True' and tz-aware Datetime.".into(),
+                ));
+            }
             if options.exact {
-                ca.as_datetime(options.fmt.as_deref(), *tu, options.cache, options.tz_aware)?
-                    .into_series()
+                ca.as_datetime(
+                    options.fmt.as_deref(),
+                    *tu,
+                    options.cache,
+                    tz_aware,
+                    options.utc,
+                    tz.as_ref(),
+                )?
+                .into_series()
             } else {
-                ca.as_datetime_not_exact(options.fmt.as_deref(), *tu)?
+                ca.as_datetime_not_exact(options.fmt.as_deref(), *tu, tz.as_ref())?
                     .into_series()
             }
         }
@@ -500,3 +539,9 @@ pub(super) fn replace(s: &[Series], literal: bool, all: bool) -> PolarsResult<Se
     }
     .map(|ca| ca.into_series())
 }
+
+#[cfg(feature = "string_from_radix")]
+pub(super) fn from_radix(s: &Series, radix: Option<u32>) -> PolarsResult<Series> {
+    let ca = s.utf8()?;
+    Ok(ca.parse_int(radix).into_series())
+}
