@@ -18,7 +18,7 @@ impl ListNameSpace {
     pub fn lengths(self) -> Expr {
         let function = |s: Series| {
             let ca = s.list()?;
-            Ok(ca.lst_lengths().into_series())
+            Ok(Some(ca.lst_lengths().into_series()))
         };
         self.0
             .map(function, GetOutput::from_type(IDX_DTYPE))
@@ -29,7 +29,7 @@ impl ListNameSpace {
     pub fn max(self) -> Expr {
         self.0
             .map(
-                |s| Ok(s.list()?.lst_max()),
+                |s| Ok(Some(s.list()?.lst_max())),
                 GetOutput::map_field(|f| {
                     if let DataType::List(adt) = f.data_type() {
                         Field::new(f.name(), *adt.clone())
@@ -46,7 +46,7 @@ impl ListNameSpace {
     pub fn min(self) -> Expr {
         self.0
             .map(
-                |s| Ok(s.list()?.lst_min()),
+                |s| Ok(Some(s.list()?.lst_min())),
                 GetOutput::map_field(|f| {
                     if let DataType::List(adt) = f.data_type() {
                         Field::new(f.name(), *adt.clone())
@@ -63,7 +63,7 @@ impl ListNameSpace {
     pub fn sum(self) -> Expr {
         self.0
             .map(
-                |s| Ok(s.list()?.lst_sum()),
+                |s| Ok(Some(s.list()?.lst_sum())),
                 GetOutput::map_field(|f| {
                     if let DataType::List(adt) = f.data_type() {
                         Field::new(f.name(), *adt.clone())
@@ -80,7 +80,7 @@ impl ListNameSpace {
     pub fn mean(self) -> Expr {
         self.0
             .map(
-                |s| Ok(s.list()?.lst_mean().into_series()),
+                |s| Ok(Some(s.list()?.lst_mean().into_series())),
                 GetOutput::from_type(DataType::Float64),
             )
             .with_fmt("arr.mean")
@@ -90,7 +90,7 @@ impl ListNameSpace {
     pub fn sort(self, options: SortOptions) -> Expr {
         self.0
             .map(
-                move |s| Ok(s.list()?.lst_sort(options).into_series()),
+                move |s| Ok(Some(s.list()?.lst_sort(options).into_series())),
                 GetOutput::same_type(),
             )
             .with_fmt("arr.sort")
@@ -100,7 +100,7 @@ impl ListNameSpace {
     pub fn reverse(self) -> Expr {
         self.0
             .map(
-                move |s| Ok(s.list()?.lst_reverse().into_series()),
+                move |s| Ok(Some(s.list()?.lst_reverse().into_series())),
                 GetOutput::same_type(),
             )
             .with_fmt("arr.reverse")
@@ -110,7 +110,7 @@ impl ListNameSpace {
     pub fn unique(self) -> Expr {
         self.0
             .map(
-                move |s| Ok(s.list()?.lst_unique()?.into_series()),
+                move |s| Ok(Some(s.list()?.lst_unique()?.into_series())),
                 GetOutput::same_type(),
             )
             .with_fmt("arr.unique")
@@ -118,8 +118,12 @@ impl ListNameSpace {
 
     /// Get items in every sublist by index.
     pub fn get(self, index: Expr) -> Expr {
-        self.0
-            .map_many_private(FunctionExpr::ListExpr(ListFunction::Get), &[index], false)
+        self.0.apply_many_private(
+            FunctionExpr::ListExpr(ListFunction::Get),
+            &[index],
+            false,
+            false,
+        )
     }
 
     /// Get items in every sublist by multiple indexes.
@@ -128,12 +132,12 @@ impl ListNameSpace {
     /// - `null_on_oob`: Return a null when an index is out of bounds.
     /// This behavior is more expensive than defaulting to returing an `Error`.
     #[cfg(feature = "list_take")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "list_take")))]
     pub fn take(self, index: Expr, null_on_oob: bool) -> Expr {
-        self.0.map_many_private(
+        self.0.apply_many_private(
             FunctionExpr::ListExpr(ListFunction::Take(null_on_oob)),
             &[index],
             false,
+            false,
         )
     }
 
@@ -153,8 +157,12 @@ impl ListNameSpace {
     pub fn join(self, separator: &str) -> Expr {
         let separator = separator.to_string();
         self.0
-            .map(
-                move |s| s.list()?.lst_join(&separator).map(|ca| ca.into_series()),
+            .apply(
+                move |s| {
+                    s.list()?
+                        .lst_join(&separator)
+                        .map(|ca| Some(ca.into_series()))
+                },
                 GetOutput::from_type(DataType::Utf8),
             )
             .with_fmt("arr.join")
@@ -164,7 +172,7 @@ impl ListNameSpace {
     pub fn arg_min(self) -> Expr {
         self.0
             .map(
-                |s| Ok(s.list()?.lst_arg_min().into_series()),
+                |s| Ok(Some(s.list()?.lst_arg_min().into_series())),
                 GetOutput::from_type(IDX_DTYPE),
             )
             .with_fmt("arr.arg_min")
@@ -174,7 +182,7 @@ impl ListNameSpace {
     pub fn arg_max(self) -> Expr {
         self.0
             .map(
-                |s| Ok(s.list()?.lst_arg_max().into_series()),
+                |s| Ok(Some(s.list()?.lst_arg_max().into_series())),
                 GetOutput::from_type(IDX_DTYPE),
             )
             .with_fmt("arr.arg_max")
@@ -182,11 +190,10 @@ impl ListNameSpace {
 
     /// Diff every sublist.
     #[cfg(feature = "diff")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "diff")))]
     pub fn diff(self, n: usize, null_behavior: NullBehavior) -> Expr {
         self.0
             .map(
-                move |s| Ok(s.list()?.lst_diff(n, null_behavior).into_series()),
+                move |s| Ok(Some(s.list()?.lst_diff(n, null_behavior).into_series())),
                 GetOutput::same_type(),
             )
             .with_fmt("arr.diff")
@@ -196,7 +203,7 @@ impl ListNameSpace {
     pub fn shift(self, periods: i64) -> Expr {
         self.0
             .map(
-                move |s| Ok(s.list()?.lst_shift(periods).into_series()),
+                move |s| Ok(Some(s.list()?.lst_shift(periods).into_series())),
                 GetOutput::same_type(),
             )
             .with_fmt("arr.shift")
@@ -204,10 +211,11 @@ impl ListNameSpace {
 
     /// Slice every sublist.
     pub fn slice(self, offset: Expr, length: Expr) -> Expr {
-        self.0.map_many_private(
+        self.0.apply_many_private(
             FunctionExpr::ListExpr(ListFunction::Slice),
             &[offset, length],
             false,
+            false,
         )
     }
 
@@ -222,7 +230,6 @@ impl ListNameSpace {
     }
 
     #[cfg(feature = "list_to_struct")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "list_to_struct")))]
     #[allow(clippy::wrong_self_convention)]
     /// Convert this `List` to a `Series` of type `Struct`. The width will be determined according to
     /// `ListToStructWidthStrategy` and the names of the fields determined by the given `name_generator`.
@@ -247,7 +254,7 @@ impl ListNameSpace {
                 move |s| {
                     s.list()?
                         .to_struct(n_fields, name_generator.clone())
-                        .map(|s| s.into_series())
+                        .map(|s| Some(s.into_series()))
                 },
                 // we don't yet know the fields
                 GetOutput::map_dtype(move |dt: &DataType| {
@@ -279,7 +286,6 @@ impl ListNameSpace {
     }
 
     #[cfg(feature = "is_in")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "is_in")))]
     /// Check if the list array contain an element
     pub fn contains<E: Into<Expr>>(self, other: E) -> Expr {
         let other = other.into();
