@@ -58,7 +58,7 @@ fn includes_null_predicate_3038() -> PolarsResult<()> {
                     s.utf8()?
                         .to_lowercase()
                         .contains("not_exist")
-                        .map(Into::into)
+                        .map(|ca| Some(ca.into_series()))
                 },
                 GetOutput::from_type(DataType::Boolean),
             ))
@@ -88,7 +88,7 @@ fn includes_null_predicate_3038() -> PolarsResult<()> {
                     s.utf8()?
                         .to_lowercase()
                         .contains_literal("non-existent")
-                        .map(Into::into)
+                        .map(|ca| Some(ca.into_series()))
                 },
                 GetOutput::from_type(DataType::Boolean),
             ))
@@ -383,3 +383,28 @@ fn test_binary_group_consistency() -> PolarsResult<()> {
 
     Ok(())
 }
+
+#[test]
+fn test_binary_null_prop() -> PolarsResult<()> {
+    let df = df![
+        "a" => [0, 0],
+        "b" => [1, 2]
+    ]?
+    .lazy();
+
+    let expr = col("a").filter(col("a").gt(lit(0)));
+
+    let out = df
+        .groupby([col("b")])
+        .agg([(expr.clone() - expr.mean()).alias("a_mean")])
+        .sort("b", Default::default())
+        .collect()?;
+
+    let a_mean: [Option<f64>; 2] = [None, None];
+    assert!(out.frame_equal_missing(&df![
+        "b" => [1, 2],
+        "a_mean" => a_mean,
+    ]?));
+
+    Ok(())
+}
