@@ -1,11 +1,9 @@
 from __future__ import annotations
 
-import warnings
 from datetime import timedelta
 from typing import TYPE_CHECKING, Callable, Generic, Iterator, Sequence, TypeVar
 
 import polars.internals as pli
-from polars.internals.dataframe.pivot import PivotOps
 from polars.utils import _timedelta_to_pl_duration, is_str_sequence
 
 if TYPE_CHECKING:
@@ -16,42 +14,12 @@ if TYPE_CHECKING:
     )
     from polars.polars import PyDataFrame
 
-# A type variable used to refer to a polars.DataFrame or any subclass of it.
-# Used to annotate DataFrame methods which returns the same type as self.
+# A type variable used to refer to a polars.DataFrame or any subclass of it
 DF = TypeVar("DF", bound="pli.DataFrame")
 
 
 class GroupBy(Generic[DF]):
-    """
-    Starts a new GroupBy operation.
-
-    You can also loop over this Object to loop over `DataFrames` with unique groups.
-
-    Examples
-    --------
-    >>> df = pl.DataFrame({"foo": ["a", "a", "b"], "bar": [1, 2, 3]})
-    >>> for group in df.groupby("foo", maintain_order=True):
-    ...     print(group)
-    ...
-    shape: (2, 2)
-    ┌─────┬─────┐
-    │ foo ┆ bar │
-    │ --- ┆ --- │
-    │ str ┆ i64 │
-    ╞═════╪═════╡
-    │ a   ┆ 1   │
-    │ a   ┆ 2   │
-    └─────┴─────┘
-    shape: (1, 2)
-    ┌─────┬─────┐
-    │ foo ┆ bar │
-    │ --- ┆ --- │
-    │ str ┆ i64 │
-    ╞═════╪═════╡
-    │ b   ┆ 3   │
-    └─────┴─────┘
-
-    """
+    """Starts a new GroupBy operation."""
 
     def __init__(
         self,
@@ -84,44 +52,77 @@ class GroupBy(Generic[DF]):
         self.maintain_order = maintain_order
 
     def __iter__(self) -> GroupBy[DF]:
-        warnings.warn(
-            "Return type of groupby iteration will change in the next breaking release."
-            " Iteration will return tuples of (group_key, data) instead of just data.",
-            category=FutureWarning,
-            stacklevel=2,
+        """
+        Allows iteration over the groups of the groupby operation.
+
+        Returns
+        -------
+        Iterator returning tuples of (name, data) for each group.
+
+        Examples
+        --------
+        >>> df = pl.DataFrame({"foo": ["a", "a", "b"], "bar": [1, 2, 3]})
+        >>> for name, data in df.groupby("foo"):  # doctest: +SKIP
+        ...     print(name)
+        ...     print(data)
+        ...
+        a
+        shape: (2, 2)
+        ┌─────┬─────┐
+        │ foo ┆ bar │
+        │ --- ┆ --- │
+        │ str ┆ i64 │
+        ╞═════╪═════╡
+        │ a   ┆ 1   │
+        │ a   ┆ 2   │
+        └─────┴─────┘
+        b
+        shape: (1, 2)
+        ┌─────┬─────┐
+        │ foo ┆ bar │
+        │ --- ┆ --- │
+        │ str ┆ i64 │
+        ╞═════╪═════╡
+        │ b   ┆ 3   │
+        └─────┴─────┘
+
+        """
+        temp_col = "__POLARS_GB_GROUP_INDICES"
+        groups_df = (
+            pli.wrap_df(self._df)
+            .lazy()
+            .with_row_count(name=temp_col)
+            .groupby(self.by, maintain_order=self.maintain_order)
+            .agg(pli.col(temp_col))
+            .collect(no_optimization=True)
         )
 
-        by = [self.by] if isinstance(self.by, (str, pli.Expr)) else self.by
+        group_names = groups_df.select(pli.all().exclude(temp_col))
 
-        # Find any single column that is not specified as 'by'
-        columns = self._df.columns()
-        by_names = {c if isinstance(c, str) else c.meta.output_name() for c in by}
-        try:
-            non_by_col = next(c for c in columns if c not in by_names)
-        except StopIteration:
-            non_by_col = None
-
-        # Get the group indices using that column
-        if non_by_col is not None:
-            groups_df = self.agg(pli.col(non_by_col).agg_groups())
-            group_indices = groups_df.select(non_by_col).to_series()
+        # When grouping by a single column, group name is a single value
+        # When grouping by multiple columns, group name is a tuple of values
+        self._group_names: Iterator[object] | Iterator[tuple[object, ...]]
+        if isinstance(self.by, (str, pli.Expr)):
+            self._group_names = iter(group_names.to_series())
         else:
-            # TODO: Properly handle expression input
-            group_indices = pli.Series([[i] for i in range(self._df.height())])
+            self._group_names = group_names.iter_rows()
 
-        self._group_indices = group_indices
+        self._group_indices = groups_df.select(temp_col).to_series()
         self._current_index = 0
 
         return self
 
-    def __next__(self) -> DF:
+    def __next__(self) -> tuple[object, DF] | tuple[tuple[object, ...], DF]:
         if self._current_index >= len(self._group_indices):
             raise StopIteration
 
         df = self._dataframe_class._from_pydf(self._df)
-        group = df[self._group_indices[self._current_index]]
+
+        group_name = next(self._group_names)
+        group_data = df[self._group_indices[self._current_index]]
         self._current_index += 1
-        return group
+
+        return group_name, group_data
 
     def apply(self, f: Callable[[pli.DataFrame], pli.DataFrame]) -> DF:
         """
@@ -173,8 +174,8 @@ class GroupBy(Generic[DF]):
 
         For each color group sample two rows:
 
-        >>> (
-        ...     df.groupby("color").apply(lambda group_df: group_df.sample(2))
+        >>> df.groupby("color").apply(
+        ...     lambda group_df: group_df.sample(2)
         ... )  # doctest: +IGNORE_RESULT
         shape: (4, 3)
         ┌─────┬───────┬──────────┐
@@ -190,8 +191,8 @@ class GroupBy(Generic[DF]):
 
         It is better to implement this with an expression:
 
-        >>> (
-        ...     df.filter(pl.arange(0, pl.count()).shuffle().over("color") < 2)
+        >>> df.filter(
+        ...     pl.arange(0, pl.count()).shuffle().over("color") < 2
         ... )  # doctest: +IGNORE_RESULT
 
         """
@@ -300,7 +301,7 @@ class GroupBy(Generic[DF]):
         df = (
             pli.wrap_df(self._df)
             .lazy()
-            .groupby(self.by, self.maintain_order)
+            .groupby(self.by, maintain_order=self.maintain_order)
             .head(n)
             .collect(no_optimization=True)
         )
@@ -337,7 +338,7 @@ class GroupBy(Generic[DF]):
         │ a       ┆ 5   │
         │ b       ┆ 6   │
         └─────────┴─────┘
-        >>> (df.groupby("letters").tail(2).sort("letters"))
+        >>> df.groupby("letters").tail(2).sort("letters")
         shape: (5, 2)
         ┌─────────┬─────┐
         │ letters ┆ nrs │
@@ -355,77 +356,12 @@ class GroupBy(Generic[DF]):
         df = (
             pli.wrap_df(self._df)
             .lazy()
-            .groupby(self.by, self.maintain_order)
+            .groupby(self.by, maintain_order=self.maintain_order)
             .tail(n)
             .collect(no_optimization=True)
         )
         return self._dataframe_class._from_pydf(df._df)
 
-    def pivot(
-        self, pivot_column: str | list[str], values_column: str | list[str]
-    ) -> PivotOps[DF]:
-        """
-        Do a pivot operation.
-
-        The pivot operation is based on the group key, a pivot column and an aggregation
-        function on the values column.
-
-        .. deprecated:: 0.13.23
-            `DataFrame.groupby.pivot` will be removed in favour of `DataFrame.pivot`.
-
-        Parameters
-        ----------
-        pivot_column
-            Column to pivot.
-        values_column
-            Column that will be aggregated.
-
-        Notes
-        -----
-        Polars'/arrow memory is not ideal for transposing operations like pivots.
-        If you have a relatively large table, consider using a groupby over a pivot.
-
-        Examples
-        --------
-        >>> df = pl.DataFrame(
-        ...     {
-        ...         "foo": ["one", "one", "one", "two", "two", "two"],
-        ...         "bar": ["A", "B", "C", "A", "B", "C"],
-        ...         "baz": [1, 2, 3, 4, 5, 6],
-        ...     }
-        ... )
-        >>> df.groupby("foo", maintain_order=True).pivot(  # doctest: +SKIP
-        ...     pivot_column="bar", values_column="baz"
-        ... ).first()
-        shape: (2, 4)
-        ┌─────┬─────┬─────┬─────┐
-        │ foo ┆ A   ┆ B   ┆ C   │
-        │ --- ┆ --- ┆ --- ┆ --- │
-        │ str ┆ i64 ┆ i64 ┆ i64 │
-        ╞═════╪═════╪═════╪═════╡
-        │ one ┆ 1   ┆ 2   ┆ 3   │
-        │ two ┆ 4   ┆ 5   ┆ 6   │
-        └─────┴─────┴─────┴─────┘
-
-        """
-        warnings.warn(
-            "`DataFrame.groupby.pivot` is deprecated and will be removed in a future"
-            " version. Use `DataFrame.pivot` instead.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        if isinstance(pivot_column, str):
-            pivot_column = [pivot_column]
-        if isinstance(values_column, str):
-            values_column = [values_column]
-        return PivotOps(
-            self._df,
-            self.by,  # type: ignore[arg-type]
-            pivot_column,
-            values_column,
-            dataframe_class=self._dataframe_class,
-        )
-
     def first(self) -> pli.DataFrame:
         """
         Aggregate the first values in the group.
@@ -726,6 +662,9 @@ class GroupBy(Generic[DF]):
         """
         Aggregate the groups into Series.
 
+        .. deprecated:: 0.16.0
+            Use ```all()``
+
         Examples
         --------
         >>> df = pl.DataFrame({"a": ["one", "two", "one", "two"], "b": [1, 2, 3, 4]})
@@ -741,7 +680,28 @@ class GroupBy(Generic[DF]):
         └─────┴───────────┘
 
         """
-        return self.agg(pli.all().list())
+        return self.agg(pli.all())
+
+    def all(self) -> pli.DataFrame:
+        """
+        Aggregate the groups into Series.
+
+        Examples
+        --------
+        >>> df = pl.DataFrame({"a": ["one", "two", "one", "two"], "b": [1, 2, 3, 4]})
+        >>> df.groupby("a", maintain_order=True).all()
+        shape: (2, 2)
+        ┌─────┬───────────┐
+        │ a   ┆ b         │
+        │ --- ┆ ---       │
+        │ str ┆ list[i64] │
+        ╞═════╪═══════════╡
+        │ one ┆ [1, 3]    │
+        │ two ┆ [2, 4]    │
+        └─────┴───────────┘
+
+        """
+        return self.agg(pli.all())
 
 
 class RollingGroupBy(Generic[DF]):
@@ -783,7 +743,7 @@ class RollingGroupBy(Generic[DF]):
                 closed=self.closed,
                 by=self.by,
             )
-            .agg(pli.col(temp_col).list())
+            .agg(pli.col(temp_col))
             .collect(no_optimization=True)
         )
 
@@ -879,7 +839,7 @@ class DynamicGroupBy(Generic[DF]):
                 by=self.by,
                 start_by=self.start_by,
             )
-            .agg(pli.col(temp_col).list())
+            .agg(pli.col(temp_col))
             .collect(no_optimization=True)
         )
 
