@@ -8,5 +8,5 @@ import pytest
 
 @pytest.fixture()
 def io_files_path() -> Path:
-    current_dir = os.path.abspath(os.path.dirname(__file__))
+    current_dir = os.path.dirname(__file__)
     return Path(current_dir) / "files"
